package com.cn.fdapfe.biz.service;

import java.util.List;
import com.cn.fdapfe.biz.domain.Workflow;

/**
 * 流程任务Service接口
 * 
 * @author Allen
 * @date 2025-03-07
 */
public interface IWorkflowService 
{
    /**
     * 查询流程任务
     * 
     * @param id 流程任务主键
     * @return 流程任务
     */
    public Workflow selectWorkflowById(Long id);

    /**
     * 查询流程任务列表
     * 
     * @param workflow 流程任务
     * @return 流程任务集合
     */
    public List<Workflow> selectWorkflowList(Workflow workflow);

    /**
     * 新增流程任务
     * 
     * @param workflow 流程任务
     * @return 结果
     */
    public int insertWorkflow(Workflow workflow);

    /**
     * 修改流程任务
     * 
     * @param workflow 流程任务
     * @return 结果
     */
    public int updateWorkflow(Workflow workflow);

    /**
     * 批量删除流程任务
     * 
     * @param ids 需要删除的流程任务主键集合
     * @return 结果
     */
    public int deleteWorkflowByIds(Long[] ids);

    /**
     * 删除流程任务信息
     * 
     * @param id 流程任务主键
     * @return 结果
     */
    public int deleteWorkflowById(Long id);
}
